@@ -3216,7 +3216,7 @@ var fbTestFixture = {
         },
         range: [0, 16],
         openingElement: {
-          type: 'JSXOpeningElement',
+          type: 'JSXOpeningFragment',
           start: 0,
           end: 2,
           loc: {
@@ -3231,11 +3231,10 @@ var fbTestFixture = {
           },
           range: [0, 2],
           attributes: [],
-          name: '',
           selfClosing: false
         },
         closingElement: {
-          type: 'JSXClosingElement',
+          type: 'JSXClosingFragment',
           start: 13,
           end: 16,
           loc: {
@@ -3248,8 +3247,7 @@ var fbTestFixture = {
               column: 16
             }
           },
-          range: [13, 16],
-          name: ''
+          range: [13, 16]
         },
         children: [{
           type: 'JSXElement',
